==> jc-1.4.0.tar.gz: soot/jimple/parser/Walker__241.h <==
// class soot.jimple.parser.Walker$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 6d7997e879c41059 java_util_AbstractSequentialList
// @dep_class 666417b6279ae396 java_util_LinkedList
// @dep_class 45e30412d3673895 soot_jimple_parser_Walker__241

// header file dependencies
// @dep_header java_util_LinkedList

#include "java/util/LinkedList.h"

#ifndef _JC_soot_jimple_parser_Walker__241_H_
#define _JC_soot_jimple_parser_Walker__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_Walker$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_Walker__241$sub_refs	_jc_soot_jimple_parser_Walker__241$sub_refs;
typedef struct _jc_soot_jimple_parser_Walker__241$sub_nonrefs	_jc_soot_jimple_parser_Walker__241$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_Walker__241$refs	_jc_soot_jimple_parser_Walker__241$refs;
typedef struct _jc_soot_jimple_parser_Walker__241$nonrefs	_jc_soot_jimple_parser_Walker__241$nonrefs;
typedef struct _jc_soot_jimple_parser_Walker__241$object	_jc_soot_jimple_parser_Walker__241$object;

typedef const struct _jc_soot_jimple_parser_Walker__241$vmethods	_jc_soot_jimple_parser_Walker__241$vmethods;
typedef const struct _jc_soot_jimple_parser_Walker__241$vtable	_jc_soot_jimple_parser_Walker__241$vtable;
typedef const struct _jc_soot_jimple_parser_Walker__241$vtype	_jc_soot_jimple_parser_Walker__241$vtype;

// Constructors
extern void _jc_soot_jimple_parser_Walker__241$method$_init$7eb18cc27bffbc60(_jc_env *, struct _jc_soot_jimple_parser_Walker__241$object *, struct _jc_soot_jimple_parser_Walker$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_Walker__241$method$removeLast$bf991ce5af172997(_jc_env *, struct _jc_soot_jimple_parser_Walker__241$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_Walker__241$method_info$removeLast$bf991ce5af172997;

// Virtual methods structure
struct _jc_soot_jimple_parser_Walker__241$vmethods {
	struct _jc_java_lang_Object$object	*(*removeLast$bf991ce5af172997)(_jc_env *, struct _jc_soot_jimple_parser_Walker__241$object *);
};

// Vtable
struct _jc_soot_jimple_parser_Walker__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_AbstractSequentialList$vmethods	java_util_AbstractSequentialList;
	_jc_java_util_LinkedList$vmethods	java_util_LinkedList;
	_jc_soot_jimple_parser_Walker__241$vmethods	soot_jimple_parser_Walker__241;
};

// Vtype
struct _jc_soot_jimple_parser_Walker__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_Walker__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_Walker__241$sub_refs {
	struct _jc_soot_jimple_parser_Walker$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_Walker__241$refs {
    _jc_soot_jimple_parser_Walker__241$sub_refs	soot_jimple_parser_Walker__241;
    _jc_java_util_LinkedList$sub_refs	java_util_LinkedList;
    _jc_java_util_AbstractSequentialList$sub_refs	java_util_AbstractSequentialList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_Walker__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_Walker__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_AbstractSequentialList$sub_nonrefs	java_util_AbstractSequentialList;
    _jc_java_util_LinkedList$sub_nonrefs	java_util_LinkedList;
    _jc_soot_jimple_parser_Walker__241$sub_nonrefs	soot_jimple_parser_Walker__241;
};

// Object instance structure
struct _jc_soot_jimple_parser_Walker__241$object {
	_jc_soot_jimple_parser_Walker__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_Walker__241$vtype	*vtype;
	_jc_soot_jimple_parser_Walker__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_Walker__241$vtype _jc_soot_jimple_parser_Walker__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_Walker__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_Walker__241$class_object;

#endif	/* _JC_soot_jimple_parser_Walker__241_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/Walker__241.h <==
// class soot.jimple.parser.Walker$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class 6d7997e879c41059 java_util_AbstractSequentialList
// @dep_class 666417b6279ae396 java_util_LinkedList
// @dep_class 45e30412d3673895 soot_jimple_parser_Walker__241

// header file dependencies
// @dep_header java_util_LinkedList

#include "java/util/LinkedList.h"

#ifndef _JC_soot_jimple_parser_Walker__241_H_
#define _JC_soot_jimple_parser_Walker__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_Walker$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_Walker__241$sub_refs	_jc_soot_jimple_parser_Walker__241$sub_refs;
typedef struct _jc_soot_jimple_parser_Walker__241$sub_nonrefs	_jc_soot_jimple_parser_Walker__241$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_Walker__241$refs	_jc_soot_jimple_parser_Walker__241$refs;
typedef struct _jc_soot_jimple_parser_Walker__241$nonrefs	_jc_soot_jimple_parser_Walker__241$nonrefs;
typedef struct _jc_soot_jimple_parser_Walker__241$object	_jc_soot_jimple_parser_Walker__241$object;

typedef const struct _jc_soot_jimple_parser_Walker__241$vmethods	_jc_soot_jimple_parser_Walker__241$vmethods;
typedef const struct _jc_soot_jimple_parser_Walker__241$vtable	_jc_soot_jimple_parser_Walker__241$vtable;
typedef const struct _jc_soot_jimple_parser_Walker__241$vtype	_jc_soot_jimple_parser_Walker__241$vtype;

// Constructors
extern void _jc_soot_jimple_parser_Walker__241$method$_init$7eb18cc27bffbc60(_jc_env *, struct _jc_soot_jimple_parser_Walker__241$object *, struct _jc_soot_jimple_parser_Walker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_Walker__241$method$removeLast$bf991ce5af172997(_jc_env *, struct _jc_soot_jimple_parser_Walker__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_Walker__241$method_info$removeLast$bf991ce5af172997;

// Virtual methods structure
struct _jc_soot_jimple_parser_Walker__241$vmethods {
	struct _jc_java_lang_Object$object	*(*removeLast$bf991ce5af172997)(_jc_env *, struct _jc_soot_jimple_parser_Walker__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_Walker__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_AbstractSequentialList$vmethods	java_util_AbstractSequentialList;
	_jc_java_util_LinkedList$vmethods	java_util_LinkedList;
	_jc_soot_jimple_parser_Walker__241$vmethods	soot_jimple_parser_Walker__241;
};

// Vtype
struct _jc_soot_jimple_parser_Walker__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_Walker__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_Walker__241$sub_refs {
	struct _jc_soot_jimple_parser_Walker$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_Walker__241$refs {
    _jc_soot_jimple_parser_Walker__241$sub_refs	soot_jimple_parser_Walker__241;
    _jc_java_util_LinkedList$sub_refs	java_util_LinkedList;
    _jc_java_util_AbstractSequentialList$sub_refs	java_util_AbstractSequentialList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_Walker__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_Walker__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_AbstractSequentialList$sub_nonrefs	java_util_AbstractSequentialList;
    _jc_java_util_LinkedList$sub_nonrefs	java_util_LinkedList;
    _jc_soot_jimple_parser_Walker__241$sub_nonrefs	soot_jimple_parser_Walker__241;
};

// Object instance structure
struct _jc_soot_jimple_parser_Walker__241$object {
	_jc_soot_jimple_parser_Walker__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_Walker__241$vtype	*vtype;
	_jc_soot_jimple_parser_Walker__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_Walker__241$vtype _jc_soot_jimple_parser_Walker__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_Walker__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_Walker__241$class_object;

#endif	/* _JC_soot_jimple_parser_Walker__241_H_ */
